@@ -59,7 +59,7 @@
 using namespace KDevelop;
 
 K_PLUGIN_FACTORY(KDevPhpSupportFactory, registerPlugin<Php::LanguageSupport>();)
-K_EXPORT_PLUGIN(KDevPhpSupportFactory(KAboutData("kdevphpsupport","kdevphp", ki18n("Php Support"), "1.0.2", ki18n("Support for Php Language"), KAboutData::License_GPL)
+K_EXPORT_PLUGIN(KDevPhpSupportFactory(KAboutData("kdevphpsupport","kdevphp", ki18n("Php Support"), "1.0.80", ki18n("Support for Php Language"), KAboutData::License_GPL)
     .addAuthor(ki18n("Milian Wolff"), ki18n("Author"), "mail@milianw.de", "http://milianw.de")
     .addAuthor(ki18n("Niko Sams"), ki18n("Author"), "niko.sams@gmail.com", "http://nikosams.blogspot.com")
 ))
@@ -129,12 +129,6 @@ QReadWriteLock* LanguageSupport::internalFunctionsLock()
 
 KDevelop::ParseJob *LanguageSupport::createParseJob(const KUrl &url)
 {
-    if ( !url.fileName().endsWith(".php") && KMimeType::findByUrl(url)->name() == "application/x-gzip"
-          && !url.fileName().endsWith(".php.gz", Qt::CaseInsensitive) )
-    {
-        // only support *.php.gz files, not arbitrary gzip files (might lead to crashes...)
-        return 0;
-    }
     return new ParseJob(url);
 }
 
@@ -194,8 +188,8 @@ bool isMagicConstant(QPair<QString, SimpleRange> word) {
     if ( word.second.isValid() && !word.second.isEmpty() ) {
         if ( word.first == "__FILE__" || word.first == "__LINE__" ||
              word.first == "__METHOD__" || word.first == "__CLASS__" ||
-             word.first == "__FUNCTION__"
-             ///TODO: php 5.3: __DIR__, __NAMESPACE__
+             word.first == "__FUNCTION__" || word.first == "__NAMESPACE__"
+             ///TODO: php 5.3: __DIR__
            )
         {
             ///TODO: maybe we should use the tokenizer to really make sure this is such a token
