@@ -26,8 +26,6 @@
 
 #include <kdebug.h>
 #include <klocale.h>
-#include <KFilterDev>
-#include <KMimeType>
 
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
@@ -111,24 +109,7 @@ void ParseJob::run()
     QString fileName = document().str();
 
     if (readFromDisk) {
-        QString mimeType = KMimeType::findByPath(fileName, 0, false)->name ();
-        if ( mimeType == "application/x-gzip" ) {
-            QIODevice* file = KFilterDev::deviceForFile (fileName, mimeType, false);
-            if ( !file->open(QIODevice::ReadOnly) ) {
-                kDebug() << "Could not open file" << document().str();
-                delete file;
-                return abortJob();
-            }
-            if (KMimeType::findByContent(file)->name() != "application/x-php") {
-                kDebug() << "gzip file" << document().str() << "does not contain PHP code";
-                delete file;
-                return abortJob();
-            }
-            session.setContents(file->readAll());
-            delete file;
-        } else {
-            session.readFile(fileName);
-        }
+        session.readFile(fileName);
     } else {
         session.setContents(contentsFromEditor());
         session.setCurrentDocument(document().str());
@@ -243,6 +224,8 @@ void ParseJob::run()
         } else {
             DUChainWriteLocker lock(DUChain::lock());
             ParsingEnvironmentFile *file = new ParsingEnvironmentFile(document());
+            /// Indexed string for 'Php', identifies environment files from this language plugin
+            static const IndexedString phpLangString("Php");
             file->setLanguage(phpLangString);
             top = new TopDUContext(document(), SimpleRange(SimpleCursor(0, 0), SimpleCursor(INT_MAX, INT_MAX)), file);
             DUChain::self()->addDocumentChain(top);
@@ -253,10 +236,6 @@ void ParseJob::run()
             top->addProblem(p);
         }
         kDebug() << "===Failed===" << document().str();
-        {
-            DUChainReadLocker lock(DUChain::lock());
-            kDebug() << DUChain::self()->chainForDocument(document());
-        }
     }
 
     cleanupSmartRevision();
